const svg = d3.select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const data = [
  { id: 'Alappuzha', name: 'Alappuzha', group: 1 },
  { id: 'Kannur', name: 'Kannur', group: 1 },
  { id: 'Eranakulam', name: 'Eranakulam', group: 1 },
  { id: 'Kottayam', name: 'Kottayam', group: 1 },
  { id: 'Kozhikode', name: 'Kozhikode', group: 1 },
  { id: 'Malappuram', name: 'Malappuram', group: 1 },
  { id: 'Palakkad', name: 'Palakkad', group: 1 },
  { id: 'Kollam', name: 'Kollam', group: 1 },
  { id: 'Thrissur', name: 'Thrissur', group: 1 },
  {
    id: 'Thiruvananthapuram',
    name: 'Thiruvananthapuram',
    group: 1,
  },
  { id: 'Kerala', name: 'Kerala', group: 2 }, // Adding Kerala as a separate node
];

const links = [
  { source: 'Alappuzha', target: 'Kannur' },
  { source: 'Alappuzha', target: 'Eranakulam' },
  { source: 'Alappuzha', target: 'Kottayam' },
  { source: 'Alappuzha', target: 'Kozhikode' },
  { source: 'Kannur', target: 'Malappuram' },
  { source: 'Eranakulam', target: 'Palakkad' },
  { source: 'Kottayam', target: 'Kollam' },
  { source: 'Kozhikode', target: 'Thrissur' },
  { source: 'Palakkad', target: 'Thiruvananthapuram' },
  { source: 'Alappuzha', target: 'Kerala' }, // Linking Kerala to Alappuzha
];

const simulation = d3
  .forceSimulation(data)
  .force(
    'link',
    d3
      .forceLink(links)
      .id((d) => d.id)
      .distance(120),
  )
  .force('charge', d3.forceManyBody().strength(-500))
  .force('center', d3.forceCenter(width / 2, height / 2));

const link = svg
  .selectAll('line')
  .data(links)
  .enter()
  .append('line')
  .attr('stroke', '#999')
  .attr('stroke-opacity', 0.6)
  .attr('stroke-width', 2);

const node = svg
  .selectAll('circle')
  .data(data)
  .enter()
  .append('circle')
  .attr('r', (d) => (d.group === 2 ? 20 : 6)) // Set radius to 20 for Kerala node, 6 for others
  .attr('fill', (d) => (d.group === 2 ? 'blue' : 'red')) // Set fill color to blue for Kerala node, red for others
  .call(
    d3
      .drag()
      .on('start', dragstarted)
      .on('drag', dragged)
      .on('end', dragended),
  );

const nodeText = svg
  .selectAll('text')
  .data(data)
  .enter()
  .append('text')
  .text((d) => d.name)
  .attr('x', (d) => d.x + 8) // Adjust the positioning of the text
  .attr('y', (d) => d.y + 3) // Adjust the positioning of the text
  .attr('font-size', (d) =>
    d.group === 2 ? '18px' : '14px',
  ); // Set font size to 18px for Kerala node, 14px for others

simulation.on('tick', () => {
  link
    .attr('x1', (d) => d.source.x)
    .attr('y1', (d) => d.source.y)
    .attr('x2', (d) => d.target.x)
    .attr('y2', (d) => d.target.y);

  node.attr('cx', (d) => d.x).attr('cy', (d) => d.y);

  nodeText
    .attr('x', (d) => d.x + 8)
    .attr('y', (d) => d.y + 3);
});

function dragstarted(event) {
  if (!event.active) simulation.alphaTarget(0.3).restart();
  event.subject.fx = event.subject.x;
  event.subject.fy = event.subject.y;
}

function dragged(event) {
  event.subject.fx = event.x;
  event.subject.fy = event.y;
}

function dragended(event) {
  if (!event.active) simulation.alphaTarget(0);
  event.subject.fx = null;
  event.subject.fy = null;
}
